#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for merging the molecules to the solvent map to create the functional
group interaction profile.

@author: mark
"""

import logging
import os
import svgutils.transform as svgt

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

FGIP_MOLECULES_FILENAME = os.path.join(os.path.dirname(__file__),
                                       "resources/FGIPmolecules.svg")

def create_fgip_from_map(map_filename):
    """This creates a FGIP from the given solvent map.
    """
    svg_figure = create_svgfigure()
    map_plot = get_svg_plot(map_filename)
    map_plot.moveto(0.0,95.0,scale=1.25)
    append_svg_plots(svg_figure, map_plot)
    output_filename = create_output_filename(map_filename)
    save_svg_figure(svg_figure, output_filename)

def save_svg_figure(svg_figure, filename):
    """This saves the figue to file.
    """
    svg_figure.save(filename)

def create_output_filename(filename, suffix="_solv_map.svg"):
    """This returns the output filename to be used.
    """
    return filename.replace(suffix, "_FGIP.svg")

def append_svg_plots(svg_figure, svg_plot):
    """This appends the plot to the figure.
    """
    svg_figure.append(svg_plot)

def get_svg_plot(svg_filename):
    """This gets the plot elements.
    """
    figure = svgt.fromfile(svg_filename)
    return figure.getroot()

def create_svgfigure():
    """This creates SVG figure using the molecules as a base.
    """
    return svgt.fromfile(FGIP_MOLECULES_FILENAME)

