#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for running the tests.

@author: mark
"""

import logging
import unittest
from solventmapcreator.test.iotest.solvationenergyreadertest import SolvationEnergyReaderTestCase
from solventmapcreator.test.iotest.solventxmlreadertest import SolventXMLReaderTestCase
from solventmapcreator.test.iotest.polynomialdatawritertest import PolynomialDataWriterTestCase
from solventmapcreator.test.iotest.polynomialdatareadertest import PolynomialDataReaderTestCase
from solventmapcreator.test.iotest.similaritymatrixwritertest import SimilarityMatrixWriterTestCase
from solventmapcreator.test.iotest.similaritymatrixreadertest import SimilarityMatrixReaderTestCase
from solventmapcreator.test.iotest.linkagewritertest import LinkageWriterTestCase
from solventmapcreator.test.iotest.solvationmapwritertest import SolvationMapWriterTestCase
from solventmapcreator.test.iotest.solvationenergyextractiontest import SolvationEnergyExtractionTestCase
from solventmapcreator.test.solvationcalculationtest.solvationcalculatortest import SolvationCalculatorTestCase
from solventmapcreator.test.solvationcalculationtest.solvationmapgeneratortest import SolvationMapGeneratorTestCase
from solventmapcreator.test.solvationcalculationtest.solvationplotinformationtest import SolvationPlotInformationTestCase
from solventmapcreator.test.solvationcalculationtest.fractionaloccupancycalculatortest import FractionalOccupancyCalculatorTestCase
from solventmapcreator.test.polynomialanalysistest.polynomialdataanalysistest import PolynomialDataAnalysisTestCase
from solventmapcreator.test.polynomialanalysistest.polynomialcomparisontest import PolynomialComparisonTestCase
from solventmapcreator.test.polynomialanalysistest.polynomialplottingtest import PolynomialPlottingTestCase
from solventmapcreator.test.polynomialanalysistest.polynomialvaluecalculatortest import PolynomialValueCalculatorTestCase
from solventmapcreator.test.clusteringanalysistest.matrixinputtest import MatrixInputTestCase
from solventmapcreator.test.clusteringanalysistest.clustercalculationtest import ClusterCalculationTestCase
from solventmapcreator.test.clusteringanalysistest.clusterstatisticstest import ClusterStatisticsTestCase
from solventmapcreator.test.clusteringanalysistest.clusteranalysistest import ClusterAnalysisTestCase
logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

IO_TEST_CASES = [SolvationEnergyReaderTestCase, SolventXMLReaderTestCase,
                 PolynomialDataWriterTestCase, PolynomialDataReaderTestCase,
                 SimilarityMatrixReaderTestCase, SimilarityMatrixWriterTestCase,
                 LinkageWriterTestCase, SolvationMapWriterTestCase,
                 SolvationEnergyExtractionTestCase]

SOLVATION_CALCULATION_TEST_CASES = [SolvationCalculatorTestCase,
                                    SolvationMapGeneratorTestCase,
                                    SolvationPlotInformationTestCase,
                                    FractionalOccupancyCalculatorTestCase]

POLYNOMIAL_ANALYSIS_TEST_CASES = [PolynomialDataAnalysisTestCase,
                                  PolynomialComparisonTestCase,
                                  PolynomialPlottingTestCase,
                                  PolynomialValueCalculatorTestCase]

CLUSTERING_ANALYSIS_TEST_CASES = [MatrixInputTestCase, ClusterCalculationTestCase,
                                  ClusterStatisticsTestCase, ClusterAnalysisTestCase]

def test_suite():
    """Function creates a test suite and then loads all the tests from the
    different test cases.
    """
    LOGGER.info("setting up loader and test suite")
    loader = unittest.TestLoader()
    suite = unittest.TestSuite()
    for test_case in IO_TEST_CASES:
        LOGGER.debug("Adding %s", test_case)
        suite.addTests(loader.loadTestsFromTestCase(test_case))
    for test_case in SOLVATION_CALCULATION_TEST_CASES:
        LOGGER.debug("Adding %s", test_case)
        suite.addTests(loader.loadTestsFromTestCase(test_case))
    for test_case in POLYNOMIAL_ANALYSIS_TEST_CASES:
        LOGGER.debug("Adding %s", test_case)
        suite.addTests(loader.loadTestsFromTestCase(test_case))
    for test_case in CLUSTERING_ANALYSIS_TEST_CASES:
        LOGGER.debug("Adding %s", test_case)
        suite.addTests(loader.loadTestsFromTestCase(test_case))
    return suite

if __name__ == '__main__':
    LOGGER.info("calling test suite method")
    SUITE = test_suite()
    LOGGER.info("running test suite")
    unittest.TextTestRunner(verbosity=2).run(SUITE)
